import { useMemo, useState } from 'react';
import {StoreOrName, useContextStore} from './ProstoreContext';
import { useConnectStore } from './useConnectStore';

/**
 * Хук, подключающий компонент к стору
 */
export function useStore<State>(storeOrName: StoreOrName<State>) {
  const store = useContextStore(storeOrName);
  const [state, setState] = useState(store.state);
  useConnectStore(store, setState);
  return state;
}

/**
 * Хук, подключащий компонент к стору и возвращающий часть состояния
 */
export function useStoreSelect<State, Derived>(storeOrName: StoreOrName<State>, select: (state: State) => Derived): Derived {
  const state = useStore(storeOrName);
  return useMemo(() => select(state), [select, state]);
}
